==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>Jeden den před začátkem</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>Připomenout zítra</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>Připomínání naplánovaného</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 až %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>Zítra</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Práce</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Soukromé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Jeden den před začátkem</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Připomenout zítra</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>o 15 minut později </translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>o 1 hodinu později </translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>o 4 hodiny později </translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Zítra</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Připomínání naplánovaného</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 až %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Jeden den před začátkem</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Zavřít</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Připomenout zítra</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Připomenout později</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Připomínání naplánovaného</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 až %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Dnes</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Zítra</translation>
    </message>
</context>
</TS>
